#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.3.0.0-H21YUUSzaLECwhEsLKCuiB
key:                  hls-fourmolu-plugin-2.3.0.0-H21YUUSzaLECwhEsLKCuiB
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5938d644ddb8d4918e3e5c1cae9fdee4
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-fourmolu-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-fourmolu-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-fourmolu-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.3.0.0-H21YUUSzaLECwhEsLKCuiB
depends:
    base-4.18.2.1 filepath-1.4.300.1
    fourmolu-0.14.0.0-ASAs8IYj2ur3JEPPkf9T9T ghc-9.6.6
    ghc-boot-th-9.6.6 ghcide-2.3.0.0-IAjr6FHxwDN2WHrf7xZzL8
    hls-plugin-api-2.3.0.0-IGiOca9xg6PAh9MaHX5nJX
    lens-5.3.5-FTj0s0XQNe34VtbjGE3NFc
    lsp-2.2.0.0-5VWxu1we8UwCjDB58kn7YJ mtl-2.3.1
    process-extras-0.7.4-LmuVOb7C1pa6hRntrhq0x4 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

